import { dataTransformer, entityTransformer } from '@stenodb/utils';
export class BrowserStorage {
    constructor(name, storage, entity, initialData) {
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "storage", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "logger", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "entityTransformer", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "dataTransformer", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        Object.defineProperty(this, "initialData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        this.name = name;
        this.storage = storage;
        this.entityTransformer = entityTransformer(entity);
        this.dataTransformer = dataTransformer(this.entityTransformer);
        if (initialData) {
            this.initialData = initialData;
        }
    }
    registerLogger(logger) {
        this.logger = logger;
    }
    read() {
        const data = this.storage.getItem(this.name);
        this.data = this.dataTransformer.toJSON(data);
        this.logger?.info('Read data:', this.data);
    }
    write() {
        this.storage.setItem(this.name, this.dataTransformer.toString(this.data));
        this.logger?.info('Write data:', this.data);
    }
    reset() {
        if (!this.initialData)
            return;
        this.data = this.entityTransformer(this.initialData);
        this.write();
    }
    exists() {
        return this.read() !== null;
    }
}
//# sourceMappingURL=WebStorage.js.map